==> pluxml_5.4.orig.tar.gz: PluXml-5.4/core/lang/nl/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Nederlands',

# common
'L_PLUXML_VERSION'				=> 'PluXml versie',
'L_HOMEPAGE'					=> 'Onthaal',
'L_UNCLASSIFIED'				=> 'Niet geclassificeerd',
'L_INFO_PHP_VERSION'			=> 'PHP-versie',
'L_INFO_MAGIC_QUOTES'			=> '"magic quotes" staan nu',
'L_INFO_CHARSET'				=> 'codering',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'De standaardlayout van PluXml werd niet gevonden',
'L_ERR_FILE_NOTFOUND'			=> 'Het gevraagde PluXml bestand kan niet gevonden worden',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina niet gevonden',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'jan',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'maart',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'mei',
'L_SHORT_JUNE'					=> 'juni',
'L_SHORT_JULY'					=> 'juli',
'L_SHORT_AUGUST'				=> 'aug',
'L_SHORT_SEPTEMBER'				=> 'sept',
'L_SHORT_OCTOBER'				=> 'okt',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'januari',
'L_FEBRUARY'					=> 'februari',
'L_MARCH'						=> 'maart',
'L_APRIL'						=> 'april',
'L_MAY'							=> 'mei',
'L_JUNE'						=> 'juni',
'L_JULY'						=> 'juli',
'L_AUGUST'						=> 'augustus',
'L_SEPTEMBER'					=> 'september',
'L_OCTOBER'						=> 'oktober',
'L_NOVEMBER'					=> 'november',
'L_DECEMBER'					=> 'december',
'L_MONDAY'						=> 'maandag',
'L_TUESDAY'						=> 'dinsdag',
'L_WEDNESDAY'					=> 'woensdag',
'L_THURSDAY'					=> 'donderdag',
'L_FRIDAY'						=> 'vrijdag',
'L_SATURDAY'					=> 'zaterdag',
'L_SUNDAY'						=> 'zondag',

# class.plx.capcha.php
'L_LAST'						=> 'laatste',
'L_FIRST'						=> 'eerste',
'L_SECOND'						=> 'tweede',
'L_THIRD'						=> 'derde',
'L_FOURTH'						=> 'vierde',
'L_FIFTH'						=> 'vijfde',
'L_SIXTH'						=> 'zesde',
'L_SEVENTH'						=> 'zevende',
'L_EIGTH'						=> 'achste',
'L_NINTH'						=> 'negende',
'L_TENTH'						=> 'tiende',
'L_NTH'							=> 'de',
'L_CAPCHA_QUESTION'				=> 'Welke is de <span class="capcha-letter">%s</span> letter van het woord <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s is toegankelijk met schrijfrechten',
'L_WRITE_NOT_ACCESS'			=> '%s is niet toegankelijk met schrijfrechten of bestaat niet',
'L_MODREWRITE_AVAILABLE'		=> 'Apache module mod_rewrite voor het herschrijven van URLs is beschikbaar',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache module mod_rewrite voor het herschrijven van URLs is niet beschikbaar',
'L_LIBGD_INSTALLED'				=> 'GD-bibliotheek is geïnstalleerd',
'L_LIBGD_NOT_INSTALLED'			=> 'GD-bibliotheek is niet geïnstalleerd of beschikbaar',
'L_MAIL_AVAILABLE'				=> 'Email verzendfunctie is beschikbaar',
'L_MAIL_NOT_AVAILABLE'			=> 'Email verzendfunctie is niet beschikbaar',

# class.plx.motor.php
'L_FILE_VERSION_REQUIRED'		=> 'Het bestand "%sversion" is nodig voor een goede werking van PluXml',
'L_ARTICLE_NO_TAG'				=> 'Geen artikel gevonden voor dit sleutelwoord !',
'L_UNKNOWN_CATEGORY'			=> 'Deze categorie bestaat niet !',
'L_NO_ARTICLE_PAGE'				=> 'Geen artikel gevonden voor deze pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Dit artikel bestaat niet of niet meer !',
'L_COM_IN_MODERATION'			=> 'De commentaar wordt momenteel gemodereerd door de beheerder van deze site',
'L_UNKNOWN_STATIC'				=> 'Deze pagina bestaat niet of niet meer !',
'L_DOCUMENT_NOT_FOUND'			=> 'Het opgevraagde document is onvindbaar',
'L_NEWCOMMENT_ERR'				=> 'Er is een fout opgetreden bij het wegschrijven van de commentaar',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Gelieve alle verplichte velden in te vullen a.u.b.',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'La vérification anti-spam a échoué',

# class.plx.show.php

'L_HTTPENCODING'				=> '%s compressie is geactiveerd',
'L_PAGETITLE_ARCHIVES'			=> 'Archieven',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'geen categorie',
'L_CATEGORY'					=> 'categorie',
'L_CATEGORIES'					=> 'categorieën',
'L_NO_ARTICLE'					=> 'geen artikel',
'L_ARTICLE'						=> 'artikel',
'L_ARTICLES'					=> 'artikels',
'L_ARTAUTHOR_UNKNOWN'			=> 'onbekend',
'L_ARTTAGS_NONE'				=> 'geen',
'L_ARTCHAPO'					=> 'Lees het vervolg #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Rss-feed van artikels uit deze categorie',
'L_ARTFEED_RSS_TAG'				=> 'Rss-feed van artikels uit deze tag',
'L_ARTFEED_RSS'					=> 'Rss-feed van de artikels',
'L_NO_COMMENT'					=> 'geen commentaar',
'L_COMMENT'						=> 'commentaar',
'L_COMMENTS'					=> 'commentaren',
'L_COMFEED_RSS_ARTICLE'			=> 'Rss-feed van de commentaren van dit artikel',
'L_COMFEED_RSS'					=> 'Rss-feed van de commentaren',
'L_STATICCONTENT_INPROCESS'		=> 'Deze pagine wordt momenteel bijgewerkt',
'L_SAID'						=> 'zei',

'L_PAGINATION_FIRST_TITLE'		=> 'Ga naar de eerste pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Vorige pagina',
'L_PAGINATION_PREVIOUS'			=> 'vorige',
'L_PAGINATION_NEXT_TITLE'		=> 'Volgende pagina',
'L_PAGINATION_NEXT'				=> 'volgende',
'L_PAGINATION_LAST_TITLE'		=> 'Ga naar de laatste pagina',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s in %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Privé URLs zijn niet geïnitialiseerd in uw instellingen !',
'L_FEED_COMMENTS'				=> 'Commentaren',
'L_FEED_ONLINE_COMMENTS'		=> 'Online commentaren',
'L_FEED_OFFLINE_COMMENTS'		=> 'Offline commentaren',
'L_FEED_WRITTEN_BY'				=> 'Geschreven door',

);
?>

==> pluxml_5.5.orig.tar.gz: PluXml-5.5/core/lang/nl/core.php <==
<?php

$LANG = array(

'L_LANGUE'						=> 'Nederlands',

'L_DATE_CREATION'				=> 'Aanmaakdatum',
'L_DATE_UPDATE'					=> 'Geactualiseerd',

# common
'L_PLUXML_VERSION'				=> 'PluXml versie',
'L_HOMEPAGE'					=> 'Onthaal',
'L_UNCLASSIFIED'				=> 'Niet geclassificeerd',
'L_INFO_PHP_VERSION'			=> 'PHP-versie',
'L_INFO_MAGIC_QUOTES'			=> '"magic quotes" staan nu',
'L_INFO_CHARSET'				=> 'codering',

# index.php
'L_ERR_THEME_NOTFOUND'			=> 'De standaardlayout van PluXml werd niet gevonden',
'L_ERR_FILE_NOTFOUND'			=> 'Het gevraagde PluXml bestand kan niet gevonden worden',
'L_ERR_PAGE_NOT_FOUND'			=> 'Pagina niet gevonden',

# class.plx.date.php
'L_SHORT_JANUARY'				=> 'jan',
'L_SHORT_FEBRUARY'				=> 'feb',
'L_SHORT_MARCH'					=> 'maart',
'L_SHORT_APRIL'					=> 'apr',
'L_SHORT_MAY'					=> 'mei',
'L_SHORT_JUNE'					=> 'juni',
'L_SHORT_JULY'					=> 'juli',
'L_SHORT_AUGUST'				=> 'aug',
'L_SHORT_SEPTEMBER'				=> 'sept',
'L_SHORT_OCTOBER'				=> 'okt',
'L_SHORT_NOVEMBER'				=> 'nov',
'L_SHORT_DECEMBER'				=> 'dec',
'L_JANUARY'						=> 'januari',
'L_FEBRUARY'					=> 'februari',
'L_MARCH'						=> 'maart',
'L_APRIL'						=> 'april',
'L_MAY'							=> 'mei',
'L_JUNE'						=> 'juni',
'L_JULY'						=> 'juli',
'L_AUGUST'						=> 'augustus',
'L_SEPTEMBER'					=> 'september',
'L_OCTOBER'						=> 'oktober',
'L_NOVEMBER'					=> 'november',
'L_DECEMBER'					=> 'december',
'L_MONDAY'						=> 'maandag',
'L_TUESDAY'						=> 'dinsdag',
'L_WEDNESDAY'					=> 'woensdag',
'L_THURSDAY'					=> 'donderdag',
'L_FRIDAY'						=> 'vrijdag',
'L_SATURDAY'					=> 'zaterdag',
'L_SUNDAY'						=> 'zondag',

# class.plx.capcha.php
'L_LAST'						=> 'laatste',
'L_FIRST'						=> 'eerste',
'L_SECOND'						=> 'tweede',
'L_THIRD'						=> 'derde',
'L_FOURTH'						=> 'vierde',
'L_FIFTH'						=> 'vijfde',
'L_SIXTH'						=> 'zesde',
'L_SEVENTH'						=> 'zevende',
'L_EIGTH'						=> 'achste',
'L_NINTH'						=> 'negende',
'L_TENTH'						=> 'tiende',
'L_NTH'							=> 'de',
'L_CAPCHA_QUESTION'				=> 'Welke is de <span class="capcha-letter">%s</span> letter van het woord <span class="capcha-word">%s</span> ?',

# class.plx.utils.php
'L_WRITE_ACCESS'				=> '%s is toegankelijk met schrijfrechten',
'L_WRITE_NOT_ACCESS'			=> '%s is niet toegankelijk met schrijfrechten of bestaat niet',
'L_MODREWRITE_AVAILABLE'		=> 'Apache module mod_rewrite voor het herschrijven van URLs is beschikbaar',
'L_MODREWRITE_NOT_AVAILABLE'	=> 'Apache module mod_rewrite voor het herschrijven van URLs is niet beschikbaar',
'L_LIBGD_INSTALLED'				=> 'GD-bibliotheek is geïnstalleerd',
'L_LIBGD_NOT_INSTALLED'			=> 'GD-bibliotheek is niet geïnstalleerd of beschikbaar',
'L_MAIL_AVAILABLE'				=> 'Email verzendfunctie is beschikbaar',
'L_MAIL_NOT_AVAILABLE'			=> 'Email verzendfunctie is niet beschikbaar',

# class.plx.motor.php
'L_ARTICLE_NO_TAG'				=> 'Geen artikel gevonden voor dit sleutelwoord !',
'L_UNKNOWN_CATEGORY'			=> 'Deze categorie bestaat niet !',
'L_NO_ARTICLE_PAGE'				=> 'Geen artikel gevonden voor deze pagina !',
'L_UNKNOWN_ARTICLE'				=> 'Dit artikel bestaat niet of niet meer !',
'L_COM_IN_MODERATION'			=> 'De commentaar wordt momenteel gemodereerd door de beheerder van deze site',
'L_UNKNOWN_STATIC'				=> 'Deze pagina bestaat niet of niet meer !',
'L_DOCUMENT_NOT_FOUND'			=> 'Het opgevraagde document is onvindbaar',
'L_NEWCOMMENT_ERR'				=> 'Er is een fout opgetreden bij het wegschrijven van de commentaar',
'L_NEWCOMMENT_FIELDS_REQUIRED'	=> 'Gelieve alle verplichte velden in te vullen a.u.b.',
'L_NEWCOMMENT_ERR_ANTISPAM'		=> 'La vérification anti-spam a échoué',

# class.plx.show.php

'L_HTTPENCODING'				=> '%s compressie is geactiveerd',
'L_PAGETITLE_ARCHIVES'			=> 'Archieven',
'L_PAGETITLE_TAG'				=> 'Tag',
'L_NO_CATEGORY'					=> 'geen categorie',
'L_CATEGORY'					=> 'categorie',
'L_CATEGORIES'					=> 'categorieën',
'L_NO_ARTICLE'					=> 'geen artikel',
'L_ARTICLE'						=> 'artikel',
'L_ARTICLES'					=> 'artikels',
'L_ARTAUTHOR_UNKNOWN'			=> 'onbekend',
'L_ARTTAGS_NONE'				=> 'geen',
'L_ARTCHAPO'					=> 'Lees het vervolg #art_title',
'L_ARTFEED_RSS_CATEGORY'		=> 'Rss-feed van artikels uit deze categorie',
'L_ARTFEED_RSS_TAG'				=> 'Rss-feed van artikels uit deze tag',
'L_ARTFEED_RSS'					=> 'Rss-feed van de artikels',
'L_NO_COMMENT'					=> 'geen commentaar',
'L_COMMENT'						=> 'commentaar',
'L_COMMENTS'					=> 'commentaren',
'L_COMFEED_RSS_ARTICLE'			=> 'Rss-feed van de commentaren van dit artikel',
'L_COMFEED_RSS'					=> 'Rss-feed van de commentaren',
'L_STATICCONTENT_INPROCESS'		=> 'Deze pagine wordt momenteel bijgewerkt',
'L_SAID'						=> 'zei',

'L_PAGINATION_FIRST_TITLE'		=> 'Ga naar de eerste pagina',
'L_PAGINATION_FIRST'			=> '«',
'L_PAGINATION_PREVIOUS_TITLE'	=> 'Vorige pagina',
'L_PAGINATION_PREVIOUS'			=> 'vorige',
'L_PAGINATION_NEXT_TITLE'		=> 'Volgende pagina',
'L_PAGINATION_NEXT'				=> 'volgende',
'L_PAGINATION_LAST_TITLE'		=> 'Ga naar de laatste pagina',
'L_PAGINATION_LAST'				=> '»',
'L_PAGINATION'					=> 'pagina %s in %s',

'L_PAGEBLOG_TITLE'				=> 'Blog',

# class.plx.feed.php
'L_FEED_NO_PRIVATE_URL'			=> 'Privé URLs zijn niet geïnitialiseerd in uw instellingen !',
'L_FEED_COMMENTS'				=> 'Commentaren',
'L_FEED_ONLINE_COMMENTS'		=> 'Online commentaren',
'L_FEED_OFFLINE_COMMENTS'		=> 'Offline commentaren',
'L_FEED_WRITTEN_BY'				=> 'Geschreven door',

);
?>
